<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// R
	'revisions_description' => 'Seguit dei moudificacioun dei ouget editourial',
	'revisions_slogan' => 'Seguit dei moudificacioun dei ouget editourial',
];
